==> estateplat-common-1.2.4-20210415.095247-717-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwHs.java <==
package cn.gtmap.estateplat.model.server.core;

import org.springframework.data.annotation.Id;

import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2015/5/7.
 */
@Table(name = "djsj_fwhs")
public class DjsjFwHs {
    @Id
    private String fwHsIndex;
    private String fwDcbIndex;
    private String bdcdyh;
    private String lszd;
    private String zl;
    private double jyjg;
    private double fttdmj;
    private double dytdmj;
    private String cqly;

    private String gyqk;
    private String fwlx;
    private String fwxz;
    private String ghyt;
    private String dycs;

    private double scjzmj;
    private double sctnjzmj;
    private double scftjzmj;

    private double ycjzmj;
    private double yctnjzmj;
    private double ycftjzmj;

    private String fjh;
    private String dyh;
    private int wlcs;
    private int sxh;
    private String hbfx;
    private int hbhs;
    private String fcdah;
    private String qlzt;
    private Double cg;


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 房屋编码
     */
    private String zjgcdy; //在建工程抵押
    private String xzzt; //限制状态
    private String ysfw; //预售范围
    private String ysyt; //预售用途
	/**
	 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
	 * @description 房屋编码
	 */
	private String fwbm;

    private String fcghyt;//房产规划用途

    private String ycfwbm;//预测房屋编码

    private String tdyt;//权籍里面增加的tdyt

    private Date qsrq;//权籍里面针对tdyt的日期
    private Date zzrq;//权籍里面针对tdyt的日期

    private String tdsyqlx;//土地使用权类型

    private String fwHstIndex;//房屋户室图
    private String bdczt;//不动产状态
    private String fjsm;//附件说明
    private String bz;//备注
    private String isfsss;//是否附属设施
    private double scglmj;//实测阁楼面积
    private double scdxsmj;//实测地下室面积
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private String fwjg;//房屋结构
    private int zcs;//总层数

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getFcghyt() {
        return fcghyt;
    }

    public void setFcghyt(String fcghyt) {
        this.fcghyt = fcghyt;
    }

    public String getYcfwbm() {
        return ycfwbm;
    }

    public void setYcfwbm(String ycfwbm) {
        this.ycfwbm = ycfwbm;
    }

    public String getFwHsIndex() {
        return fwHsIndex;
    }

    public void setFwHsIndex(String fwHsIndex) {
        this.fwHsIndex = fwHsIndex;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public double getJyjg() {
        return jyjg;
    }

    public void setJyjg(double jyjg) {
        this.jyjg = jyjg;
    }

    public double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }

    public double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public double getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(double sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public double getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(double scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public int getWlcs() {
        return wlcs;
    }

    public void setWlcs(int wlcs) {
        this.wlcs = wlcs;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getHbfx() {
        return hbfx;
    }

    public void setHbfx(String hbfx) {
        this.hbfx = hbfx;
    }

    public int getHbhs() {
        return hbhs;
    }

    public void setHbhs(int hbhs) {
        this.hbhs = hbhs;
    }

    public String getFcdah() {
        return fcdah;
    }

    public void setFcdah(String fcdah) {
        this.fcdah = fcdah;
    }

    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getYsfw() {
        return ysfw;
    }

    public void setYsfw(String ysfw) {
        this.ysfw = ysfw;
    }

    public String getZjgcdy() {
        return zjgcdy;
    }

    public void setZjgcdy(String zjgcdy) {
        this.zjgcdy = zjgcdy;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getYsyt() {
        return ysyt;
    }

    public void setYsyt(String ysyt) {
        this.ysyt = ysyt;
    }

	public String getFwbm() {
		return fwbm;
	}

	public void setFwbm(String fwbm) {
		this.fwbm = fwbm;
	}

    public String getFwHstIndex() {
        return fwHstIndex;
    }

    public void setFwHstIndex(String fwHstIndex) {
        this.fwHstIndex = fwHstIndex;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public String getFjsm() {
        return fjsm;
    }

    public void setFjsm(String fjsm) {
        this.fjsm = fjsm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIsfsss() {
        return isfsss;
    }

    public void setIsfsss(String isfsss){
        this.isfsss = isfsss;
    }

    public double getScglmj() {
        return scglmj;
    }

    public void setScglmj(double scglmj) {
        this.scglmj = scglmj;
    }

    public double getScdxsmj() {
        return scdxsmj;
    }

    public void setScdxsmj(double scdxsmj) {
        this.scdxsmj = scdxsmj;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getZcs() {
        return zcs;
    }

    public void setZcs(int zcs) {
        this.zcs = zcs;
    }
}

==> estateplat-common-1.2.4-20210721.090507-825-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwHs.java <==
package cn.gtmap.estateplat.model.server.core;

import org.springframework.data.annotation.Id;

import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2015/5/7.
 */
@Table(name = "djsj_fwhs")
public class DjsjFwHs {
    @Id
    private String fwHsIndex;
    private String fwDcbIndex;
    private String bdcdyh;
    private String lszd;
    private String zl;
    private double jyjg;
    private double fttdmj;
    private double dytdmj;
    private String cqly;

    private String gyqk;
    private String fwlx;
    private String fwxz;
    private String ghyt;
    private String dycs;

    private double scjzmj;
    private double sctnjzmj;
    private double scftjzmj;

    private double ycjzmj;
    private double yctnjzmj;
    private double ycftjzmj;

    private String fjh;
    private String dyh;
    private int wlcs;
    private int sxh;
    private String hbfx;
    private int hbhs;
    private String fcdah;
    private String qlzt;
    private Double cg;


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 房屋编码
     */
    private String zjgcdy; //在建工程抵押
    private String xzzt; //限制状态
    private String ysfw; //预售范围
    private String ysyt; //预售用途
	/**
	 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
	 * @description 房屋编码
	 */
	private String fwbm;

    private String fcghyt;//房产规划用途

    private String ycfwbm;//预测房屋编码

    private String tdyt;//权籍里面增加的tdyt

    private Date qsrq;//权籍里面针对tdyt的日期
    private Date zzrq;//权籍里面针对tdyt的日期

    private String tdsyqlx;//土地使用权类型

    private String fwHstIndex;//房屋户室图
    private String bdczt;//不动产状态
    private String fjsm;//附件说明
    private String bz;//备注
    private String isfsss;//是否附属设施
    private double scglmj;//实测阁楼面积
    private double scdxsmj;//实测地下室面积
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private String fwjg;//房屋结构
    private int zcs;//总层数
    private String hstdz;//户室图地址

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getFcghyt() {
        return fcghyt;
    }

    public void setFcghyt(String fcghyt) {
        this.fcghyt = fcghyt;
    }

    public String getYcfwbm() {
        return ycfwbm;
    }

    public void setYcfwbm(String ycfwbm) {
        this.ycfwbm = ycfwbm;
    }

    public String getFwHsIndex() {
        return fwHsIndex;
    }

    public void setFwHsIndex(String fwHsIndex) {
        this.fwHsIndex = fwHsIndex;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public double getJyjg() {
        return jyjg;
    }

    public void setJyjg(double jyjg) {
        this.jyjg = jyjg;
    }

    public double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }

    public double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public double getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(double sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public double getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(double scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public int getWlcs() {
        return wlcs;
    }

    public void setWlcs(int wlcs) {
        this.wlcs = wlcs;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getHbfx() {
        return hbfx;
    }

    public void setHbfx(String hbfx) {
        this.hbfx = hbfx;
    }

    public int getHbhs() {
        return hbhs;
    }

    public void setHbhs(int hbhs) {
        this.hbhs = hbhs;
    }

    public String getFcdah() {
        return fcdah;
    }

    public void setFcdah(String fcdah) {
        this.fcdah = fcdah;
    }

    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getYsfw() {
        return ysfw;
    }

    public void setYsfw(String ysfw) {
        this.ysfw = ysfw;
    }

    public String getZjgcdy() {
        return zjgcdy;
    }

    public void setZjgcdy(String zjgcdy) {
        this.zjgcdy = zjgcdy;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getYsyt() {
        return ysyt;
    }

    public void setYsyt(String ysyt) {
        this.ysyt = ysyt;
    }

	public String getFwbm() {
		return fwbm;
	}

	public void setFwbm(String fwbm) {
		this.fwbm = fwbm;
	}

    public String getFwHstIndex() {
        return fwHstIndex;
    }

    public void setFwHstIndex(String fwHstIndex) {
        this.fwHstIndex = fwHstIndex;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public String getFjsm() {
        return fjsm;
    }

    public void setFjsm(String fjsm) {
        this.fjsm = fjsm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIsfsss() {
        return isfsss;
    }

    public void setIsfsss(String isfsss){
        this.isfsss = isfsss;
    }

    public double getScglmj() {
        return scglmj;
    }

    public void setScglmj(double scglmj) {
        this.scglmj = scglmj;
    }

    public double getScdxsmj() {
        return scdxsmj;
    }

    public void setScdxsmj(double scdxsmj) {
        this.scdxsmj = scdxsmj;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getZcs() {
        return zcs;
    }

    public void setZcs(int zcs) {
        this.zcs = zcs;
    }

    public String getHstdz() {
        return hstdz;
    }

    public void setHstdz(String hstdz) {
        this.hstdz = hstdz;
    }
}
